# Users - Classroom - Profile
- [API documentation](#api-documentation)
- [Definitions](#definitions)
- [Display Classroom profile](#display-classroom-profile)

## API documentation
* [Classroom API - User Profiles](https://developers.google.com/classroom/reference/rest/v1/userProfiles/get)

## Definitions
* [`<UserTypeEntity>`](Collections-of-Users)

## Display Classroom profile
```
gam <UserTypeEntity> show classroomprofile
gam <UserTypeEntity> print classroomprofile [todrive <ToDriveAttribute>*]
```
